@@ -86,4 +86,18 @@ ui_div2 <- function(id, zoomable, letlasso, sel_array_name, selected_class, zoom
   paste0(bar_, "</div>")
 }
 
-#
+
+#' @section Geoms:
+#'
+#' All `geom_*_interactive` functions (like `geom_point_interactive`) return a layer that
+#' contains a `GeomInteractive*` object (like `GeomInteractivePoint`). The `Geom*`
+#' object is responsible for rendering the data in the plot.
+#'
+#' See \code{\link[ggplot2]{Geom}} for more information.
+#' @rdname ggiraph-ggproto
+#' @format NULL
+#' @usage NULL
+#' @title ggproto classes for ggiraph
+#' @name GeomInteractive
+NULL
+
